@@ -13,9 +13,22 @@ def depict(
     useCDKAtomPalette=True,
     explicitMethyl=True,
     scaleBondWidth=False,
-    addStereoAnnotation = True,
+    addStereoAnnotation=True,
 ):
     mol = parse_molblock(molfile)
+    if not mol:
+        return None
+
+    # ChEBI doesn't like to show '#'
+    # nor superindices in numbered R groups
+    for at in mol.GetAtoms():
+        dlabel = at.GetSymbol()
+        if len(dlabel) > 1 and dlabel[0] == "R":
+            if dlabel[1] == "#":
+                at.SetProp("_displayLabel", "R")
+            else:
+                at.SetProp("_displayLabel", f"R{dlabel[1:]}")
+
     draw = rdMolDraw2D.MolDraw2DSVG(width, height)
     draw_options = draw.drawOptions()
     draw_options.baseFontSize = baseFontSize
